@@ -23,14 +23,29 @@ class ClefOAuth2(BaseOAuth2):
         params['redirect_url'] = params.pop('redirect_uri')
         return params
 
+    def get_user_id(self, response, details):
+        return details.get('info').get('id')
+
     def get_user_details(self, response):
         """Return user details from Github account"""
         info = response.get('info')
+        fullname, first_name, last_name = self.get_user_names(
+            first_name=info.get('first_name'),
+            last_name=info.get('last_name')
+        )
+
+        email = info.get('email', '')
+        if email:
+            username = email.split('@', 1)[0]
+        else:
+            username = info.get('id')
+
         return {
-            'username': response.get('clef_id'),
-            'email': info.get('email', ''),
-            'first_name': info.get('first_name'),
-            'last_name': info.get('last_name'),
+            'username': username,
+            'email': email,
+            'fullname': fullname,
+            'first_name': first_name,
+            'last_name': last_name,
             'phone_number': info.get('phone_number', '')
         }
 
