@@ -38,6 +38,6 @@ class FlickrOAuth(BaseOAuth1):
 
     def auth_extra_arguments(self):
         params = super(FlickrOAuth, self).auth_extra_arguments() or {}
-        if not 'perms' in params:
+        if 'perms' not in params:
             params['perms'] = 'read'
         return params
