@@ -4,22 +4,29 @@ Github OAuth2 backend, docs at:
 """
 from requests import HTTPError
 
-from social.exceptions import AuthFailed
+from six.moves.urllib.parse import urljoin
+
 from social.backends.oauth import BaseOAuth2
+from social.exceptions import AuthFailed
 
 
 class GithubOAuth2(BaseOAuth2):
     """Github OAuth authentication backend"""
     name = 'github'
+    API_URL = 'https://api.github.com/'
     AUTHORIZATION_URL = 'https://github.com/login/oauth/authorize'
     ACCESS_TOKEN_URL = 'https://github.com/login/oauth/access_token'
     ACCESS_TOKEN_METHOD = 'POST'
     SCOPE_SEPARATOR = ','
     EXTRA_DATA = [
         ('id', 'id'),
-        ('expires', 'expires')
+        ('expires', 'expires'),
+        ('login', 'login')
     ]
 
+    def api_url(self):
+        return self.API_URL
+
     def get_user_details(self, response):
         """Return user details from Github account"""
         fullname, first_name, last_name = self.get_user_names(
@@ -36,17 +43,25 @@ class GithubOAuth2(BaseOAuth2):
         data = self._user_data(access_token)
         if not data.get('email'):
             try:
-                email = self._user_data(access_token, '/emails')[0]
-            except (HTTPError, IndexError, ValueError, TypeError):
-                email = ''
+                emails = self._user_data(access_token, '/emails')
+            except (HTTPError, ValueError, TypeError):
+                emails = []
 
-            if isinstance(email, dict):
-                email = email.get('email', '')
-            data['email'] = email
+            if emails:
+                email = emails[0]
+                primary_emails = [
+                    e for e in emails
+                    if not isinstance(e, dict) or e.get('primary')
+                ]
+                if primary_emails:
+                    email = primary_emails[0]
+                if isinstance(email, dict):
+                    email = email.get('email', '')
+                data['email'] = email
         return data
 
     def _user_data(self, access_token, path=None):
-        url = 'https://api.github.com/user{0}'.format(path or '')
+        url = urljoin(self.api_url(), 'user{0}'.format(path or ''))
         return self.get_json(url, params={'access_token': access_token})
 
 
@@ -80,10 +95,13 @@ class GithubOrganizationOAuth2(GithubMemberOAuth2):
     no_member_string = 'User doesn\'t belong to the organization'
 
     def member_url(self, user_data):
-        return 'https://api.github.com/orgs/{org}/members/{username}'\
-                    .format(org=self.setting('NAME'),
-                            username=user_data.get('login'))
-
+        return urljoin(
+            self.api_url(),
+            'orgs/{org}/members/{username}'.format(
+                org=self.setting('NAME'),
+                username=user_data.get('login')
+            )
+        )
 
 
 class GithubTeamOAuth2(GithubMemberOAuth2):
@@ -92,6 +110,10 @@ class GithubTeamOAuth2(GithubMemberOAuth2):
     no_member_string = 'User doesn\'t belong to the team'
 
     def member_url(self, user_data):
-        return 'https://api.github.com/teams/{team_id}/members/{username}'\
-                    .format(team_id=self.setting('ID'),
-                            username=user_data.get('login'))
+        return urljoin(
+            self.api_url(),
+            'teams/{team_id}/members/{username}'.format(
+                team_id=self.setting('ID'),
+                username=user_data.get('login')
+            )
+        )
