@@ -22,9 +22,14 @@ class TrelloOAuth(BaseOAuth1):
 
     def get_user_details(self, response):
         """Return user details from Trello account"""
+        fullname, first_name, last_name = self.get_user_names(
+            response.get('fullName')
+        )
         return {'username': response.get('username'),
                 'email': response.get('email'),
-                'fullName': response.get('fullName')}
+                'fullname': fullname,
+                'first_name': first_name,
+                'last_name': last_name}
 
     def user_data(self, access_token):
         """Return user data provided"""
@@ -33,3 +38,10 @@ class TrelloOAuth(BaseOAuth1):
             return self.get_json(url, auth=self.oauth_auth(access_token))
         except ValueError:
             return None
+
+    def auth_extra_arguments(self):
+        return {
+            'name': self.setting('APP_NAME', ''),
+            # trello default expiration is '30days'
+            'expiration': self.setting('EXPIRATION', 'never')
+        }
