@@ -1,5 +1,6 @@
 """
-Twilio support
+Twilio auth backend, docs at:
+    http://psa.matiasaguirre.net/docs/backends/twilio.html
 """
 from re import sub
 
