@@ -10,6 +10,8 @@ class TwitterOAuth(BaseOAuth1):
     """Twitter OAuth authentication backend"""
     name = 'twitter'
     EXTRA_DATA = [('id', 'id')]
+    REQUEST_TOKEN_METHOD = 'POST'
+    ACCESS_TOKEN_METHOD = 'POST'
     AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authenticate'
     REQUEST_TOKEN_URL = 'https://api.twitter.com/oauth/request_token'
     ACCESS_TOKEN_URL = 'https://api.twitter.com/oauth/access_token'
@@ -25,7 +27,7 @@ class TwitterOAuth(BaseOAuth1):
         """Return user details from Twitter account"""
         fullname, first_name, last_name = self.get_user_names(response['name'])
         return {'username': response['screen_name'],
-                'email': '',  # not supplied
+                'email': response.get('email', ''),
                 'fullname': fullname,
                 'first_name': first_name,
                 'last_name': last_name}
@@ -34,5 +36,6 @@ class TwitterOAuth(BaseOAuth1):
         """Return user data provided"""
         return self.get_json(
             'https://api.twitter.com/1.1/account/verify_credentials.json',
+            params={'include_email': 'true'},
             auth=self.oauth_auth(access_token)
         )
