@@ -8,7 +8,7 @@ from social.backends.oauth import BaseOAuth1
 class XingOAuth(BaseOAuth1):
     """Xing OAuth authentication backend"""
     name = 'xing'
-    AUTHORIZATION_URL = 'https://www.xing.com/v1/authorize'
+    AUTHORIZATION_URL = 'https://api.xing.com/v1/authorize'
     REQUEST_TOKEN_URL = 'https://api.xing.com/v1/request_token'
     ACCESS_TOKEN_URL = 'https://api.xing.com/v1/access_token'
     SCOPE_SEPARATOR = '+'
@@ -19,10 +19,13 @@ class XingOAuth(BaseOAuth1):
 
     def get_user_details(self, response):
         """Return user details from Xing account"""
-        first_name, last_name = response['first_name'], response['last_name']
         email = response.get('email', '')
+        fullname, first_name, last_name = self.get_user_names(
+            first_name=response['first_name'],
+            last_name=response['last_name']
+        )
         return {'username': first_name + last_name,
-                'fullname': first_name + ' ' + last_name,
+                'fullname': fullname,
                 'first_name': first_name,
                 'last_name': last_name,
                 'email': email}
