@@ -41,6 +41,10 @@ class AuthFailed(AuthException):
 
 class AuthCanceled(AuthException):
     """Auth process was canceled by user."""
+    def __init__(self, *args, **kwargs):
+        self.response = kwargs.pop('response', None)
+        super(AuthCanceled, self).__init__(*args, **kwargs)
+
     def __str__(self):
         return 'Authentication process canceled'
 
@@ -98,6 +102,12 @@ class AuthForbidden(AuthException):
         return 'Your credentials aren\'t allowed'
 
 
+class AuthUnreachableProvider(AuthException):
+    """Cannot reach the provider"""
+    def __str__(self):
+        return 'The authentication provider could not be reached'
+
+
 class InvalidEmail(AuthException):
     def __str__(self):
         return 'Email couldn\'t be validated'
