@@ -2,8 +2,8 @@ from social.exceptions import AuthAlreadyAssociated, AuthException, \
                               AuthForbidden
 
 
-def social_details(backend, response, *args, **kwargs):
-    return {'details': backend.get_user_details(response)}
+def social_details(backend, details, response, *args, **kwargs):
+    return {'details': dict(backend.get_user_details(response), **details)}
 
 
 def social_uid(backend, details, response, *args, **kwargs):
@@ -27,7 +27,7 @@ def social_user(backend, uid, user=None, *args, **kwargs):
     return {'social': social,
             'user': user,
             'is_new': user is None,
-            'new_association': False}
+            'new_association': social is None}
 
 
 def associate_user(backend, uid, user=None, social=None, *args, **kwargs):
@@ -76,12 +76,14 @@ def associate_by_email(backend, details, user=None, *args, **kwargs):
                 'The given email address is associated with another account'
             )
         else:
-            return {'user': users[0]}
+            return {'user': users[0],
+                    'is_new': False}
 
 
 def load_extra_data(backend, details, response, uid, user, *args, **kwargs):
     social = kwargs.get('social') or \
              backend.strategy.storage.user.get_social_auth(backend.name, uid)
     if social:
-        extra_data = backend.extra_data(user, uid, response, details)
+        extra_data = backend.extra_data(user, uid, response, details,
+                                        *args, **kwargs)
         social.set_extra_data(extra_data)
