@@ -3,6 +3,8 @@ import re
 import time
 import base64
 import uuid
+import warnings
+
 from datetime import datetime, timedelta
 
 import six
@@ -13,7 +15,7 @@ from social.backends.utils import get_backend
 from social.strategies.utils import get_current_strategy
 
 
-CLEAN_USERNAME_REGEX = re.compile(r'[^\w.@+-_]+', re.UNICODE)
+CLEAN_USERNAME_REGEX = re.compile(r'[^\w.@+_-]+', re.UNICODE)
 
 
 class UserMixin(object):
@@ -34,10 +36,15 @@ class UserMixin(object):
             return Backend(strategy=strategy)
 
     @property
-    def tokens(self):
+    def access_token(self):
         """Return access_token stored in extra_data or None"""
         return self.extra_data.get('access_token')
 
+    @property
+    def tokens(self):
+        warnings.warn('tokens is deprecated, use access_token instead')
+        return self.access_token
+
     def refresh_token(self, strategy, *args, **kwargs):
         token = self.extra_data.get('refresh_token') or \
                 self.extra_data.get('access_token')
@@ -45,14 +52,7 @@ class UserMixin(object):
         if token and backend and hasattr(backend, 'refresh_token'):
             backend = backend(strategy=strategy)
             response = backend.refresh_token(token, *args, **kwargs)
-            access_token = response.get('access_token')
-            refresh_token = response.get('refresh_token')
-
-            if access_token or refresh_token:
-                if access_token:
-                    self.extra_data['access_token'] = access_token
-                if refresh_token:
-                    self.extra_data['refresh_token'] = refresh_token
+            if self.set_extra_data(response):
                 self.save()
 
     def expiration_datetime(self):
@@ -81,7 +81,8 @@ class UserMixin(object):
 
     def set_extra_data(self, extra_data=None):
         if extra_data and self.extra_data != extra_data:
-            if self.extra_data:
+            if self.extra_data and not isinstance(
+                    self.extra_data, six.string_types):
                 self.extra_data.update(extra_data)
             else:
                 self.extra_data = extra_data
@@ -188,9 +189,8 @@ class AssociationMixin(object):
         kwargs = {'server_url': server_url}
         if handle is not None:
             kwargs['handle'] = handle
-        return sorted([
-            (assoc.id, cls.openid_association(assoc))
-                for assoc in cls.get(**kwargs)
+        return sorted([(assoc.id, cls.openid_association(assoc))
+            for assoc in cls.get(**kwargs)
         ], key=lambda x: x[1].issued, reverse=True)
 
     @classmethod
