@@ -1,6 +1,9 @@
 """Django ORM models for Social Auth"""
 import base64
 import six
+import sys
+from django.db import transaction
+from django.db.utils import IntegrityError
 
 from social.storage.base import UserMixin, AssociationMixin, NonceMixin, \
                                 CodeMixin, BaseStorage
@@ -54,20 +57,38 @@ class DjangoUserMixin(UserMixin):
 
     @classmethod
     def create_user(cls, *args, **kwargs):
-        if 'username' in kwargs:
-            kwargs[cls.username_field()] = kwargs.pop('username')
-        return cls.user_model().objects.create_user(*args, **kwargs)
+        username_field = cls.username_field()
+        if 'username' in kwargs and username_field not in kwargs:
+            kwargs[username_field] = kwargs.pop('username')
+        try:
+            user = cls.user_model().objects.create_user(*args, **kwargs)
+        except IntegrityError:
+            # User might have been created on a different thread, try and find them.
+            # If we don't, re-raise the IntegrityError.
+            exc_info = sys.exc_info()
+            # If email comes in as None it won't get found in the get
+            if kwargs.get('email', True) is None:
+                kwargs['email'] = ''
+            try:
+                user = cls.user_model().objects.get(*args, **kwargs)
+            except cls.user_model().DoesNotExist:
+                six.reraise(*exc_info)
+        return user
 
     @classmethod
-    def get_user(cls, pk):
+    def get_user(cls, pk=None, **kwargs):
+        if pk:
+            kwargs = {'pk': pk}
         try:
-            return cls.user_model().objects.get(pk=pk)
+            return cls.user_model().objects.get(**kwargs)
         except cls.user_model().DoesNotExist:
             return None
 
     @classmethod
     def get_users_by_email(cls, email):
-        return cls.user_model().objects.filter(email__iexact=email)
+        user_model = cls.user_model()
+        email_field = getattr(user_model, 'EMAIL_FIELD', 'email')
+        return user_model.objects.filter(**{email_field + '__iexact': email})
 
     @classmethod
     def get_social_auth(cls, provider, uid):
@@ -91,7 +112,16 @@ class DjangoUserMixin(UserMixin):
     def create_social_auth(cls, user, uid, provider):
         if not isinstance(uid, six.string_types):
             uid = str(uid)
-        return cls.objects.create(user=user, uid=uid, provider=provider)
+        if hasattr(transaction, 'atomic'):
+            # In Django versions that have an "atomic" transaction decorator / context
+            # manager, there's a transaction wrapped around this call.
+            # If the create fails below due to an IntegrityError, ensure that the transaction
+            # stays undamaged by wrapping the create in an atomic.
+            with transaction.atomic():
+                social_auth = cls.objects.create(user=user, uid=uid, provider=provider)
+        else:
+            social_auth = cls.objects.create(user=user, uid=uid, provider=provider)
+        return social_auth
 
 
 class DjangoNonceMixin(NonceMixin):
